@@ -39,9 +39,10 @@ class api:
         response.status_code = 200
         response.text = "Blank"
         with open("access-log.txt", "a") as f:
-            f.write("/n")
-            f.write(('127.0.0.1 - - ['+(datetime.date.today().__str__())+' '+(datetime.datetime.now().strftime("%H:%M:%S"))+ '] GET / HTTP/1.1" 200').encode())
-            f.write("/n")
+            f.write("\n")
+            f.write(('127.0.0.1 - - ['+(datetime.date.today().__str__())+' '+(datetime.datetime.now().strftime("%H:%M:%S"))+ '] GET / HTTP/1.1" 200'))
+            f.write(request)
+            f.write("\n")
         
         handler = self.find_handler(request)
 
